==> kenetsu-0.1.3.tar.gz: kenetsu-0.1.3/tests/test_maillogeater.py <==
import unittest
import copy
import json

from maileater import MailLogEater


class TestTailLoader(unittest.TestCase):
    EMPTY_COUNTER = {
        "bounced": 0,
        "deferred": 0,
        "sent": 0,
        "expired": 0,
    }

    def setUp(self):
        self.expected = copy.deepcopy(TestTailLoader.EMPTY_COUNTER)

    # line is properly parsed and counted/uncounted
    def test_eat_sent(self):
        eater = MailLogEater()
        eater.eat("xxx status=sent xxx")
        self.expected["sent"] = 1
        self.assertEqual(eater.counter, self.expected)

    def test_eat_deferred(self):
        eater = MailLogEater()
        eater.eat("xxx status=deferred xxx")
        self.expected["deferred"] = 1
        self.assertEqual(eater.counter, self.expected)

    def test_eat_bounced(self):
        eater = MailLogEater()
        eater.eat("xxx status=bounced xxx")
        self.expected["bounced"] = 1
        self.assertEqual(eater.counter, self.expected)

    def test_eat_expired(self):
        eater = MailLogEater()
        eater.eat("xxx status=expired xxx")
        self.expected["expired"] = 1
        self.assertEqual(eater.counter, self.expected)

    # counter is retained over loop
    def test_retention(self):
        eater = MailLogEater()
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=deferred xxx")
        self.expected["sent"] = 2
        self.expected["deferred"] = 1
        self.assertEqual(eater.counter, self.expected)

    # status is properly formatted
    # - included counter is correct
    # - formatted as one line string (without newline)
    def test_retention(self):
        eater = MailLogEater()
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=deferred xxx")
        self.expected["sent"] = 2
        self.expected["deferred"] = 1
        output = str(eater)
        self.assertFalse("\n" in output)
        json_output = json.loads(output)
        self.assertEqual(json_output, self.expected)

==> kenetsu-0.2.0.tar.gz: kenetsu-0.2.0/tests/test_maillogeater.py <==
import unittest
import copy
import json

from maileater import MailLogEater


class TestTailLoader(unittest.TestCase):
    EMPTY_COUNTER = {
        "bounced": 0,
        "deferred": 0,
        "sent": 0,
        "expired": 0,
    }

    def setUp(self):
        self.expected = copy.deepcopy(TestTailLoader.EMPTY_COUNTER)

    # line is properly parsed and counted/uncounted
    def test_eat_sent(self):
        eater = MailLogEater()
        eater.eat("xxx status=sent xxx")
        self.expected["sent"] = 1
        self.assertEqual(eater.counter, self.expected)

    def test_eat_deferred(self):
        eater = MailLogEater()
        eater.eat("xxx status=deferred xxx")
        self.expected["deferred"] = 1
        self.assertEqual(eater.counter, self.expected)

    def test_eat_bounced(self):
        eater = MailLogEater(["postfix/local"])
        eater.eat("postfix/smtp[11111] 1234ABCD: status=bounced xxx")
        # This line should be excluded
        eater.eat("postfix/local[11111] 1234ABCD: yyy status=bounced yyy")
        self.expected["bounced"] = 1
        self.assertEqual(eater.counter, self.expected)

    def test_eat_expired(self):
        eater = MailLogEater()
        eater.eat("xxx status=expired xxx")
        self.expected["expired"] = 1
        self.assertEqual(eater.counter, self.expected)

    # counter is retained over loop
    def test_retention(self):
        eater = MailLogEater()
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=deferred xxx")
        self.expected["sent"] = 2
        self.expected["deferred"] = 1
        self.assertEqual(eater.counter, self.expected)

    # status is properly formatted
    # - included counter is correct
    # - formatted as one line string (without newline)
    def test_retention(self):
        eater = MailLogEater()
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=sent xxx")
        eater.eat("xxx status=deferred xxx")
        self.expected["sent"] = 2
        self.expected["deferred"] = 1
        output = str(eater)
        self.assertFalse("\n" in output)
        json_output = json.loads(output)
        self.assertEqual(json_output, self.expected)
